@@ -3,6 +3,9 @@ from commitlyCLI.cli import CommitlyCLI
 from sys import platform
 from os import system
 
-if __name__ == "__main__":
+def main():
     system('cls' if platform == 'win32' else 'clear')
-    CommitlyCLI().run()
\ No newline at end of file
+    CommitlyCLI().run()
+
+if __name__ == "__main__":
+    main()
\ No newline at end of file
